@@ -1,10 +1,13 @@
 use number_traits::Num;
 
-
 #[inline(always)]
-pub fn new<T: Copy + Num>(x: T, y: T) -> [T; 2] {[x, y]}
+pub fn new<T: Copy + Num>(x: T, y: T) -> [T; 2] {
+    [x, y]
+}
 #[inline(always)]
-pub fn create<T: Copy + Num>(x: T, y: T) -> [T; 2] {new(x, y)}
+pub fn create<T: Copy + Num>(x: T, y: T) -> [T; 2] {
+    new(x, y)
+}
 #[test]
 fn test_new() {
     let v = new(1, 2);
@@ -13,7 +16,9 @@ fn test_new() {
 }
 
 #[inline(always)]
-pub fn clone<'b, T: Copy + Num>(v: &'b [T; 2]) -> [T; 2] {new(v[0], v[1])}
+pub fn clone<'b, T: Copy + Num>(v: &'b [T; 2]) -> [T; 2] {
+    new(v[0], v[1])
+}
 
 #[inline]
 pub fn copy<'a, 'b, T: Copy + Num>(out: &'a mut [T; 2], a: &'b [T; 2]) -> &'a mut [T; 2] {
