@@ -1,8 +1,11 @@
 use number_traits::Num;
 
-
 #[inline]
-pub fn sub<'a, 'b, T: Copy + Num>(out: &'a mut [T; 2], a: &'b [T; 2], b: &'b [T; 2]) ->  &'a mut [T; 2] {
+pub fn sub<'a, 'b, T: Copy + Num>(
+    out: &'a mut [T; 2],
+    a: &'b [T; 2],
+    b: &'b [T; 2],
+) -> &'a mut [T; 2] {
     out[0] = a[0] - b[0];
     out[1] = a[1] - b[1];
     out
@@ -16,7 +19,7 @@ fn test_sub() {
 }
 
 #[inline]
-pub fn ssub<'a, 'b, T: Copy + Num>(out: &'a mut [T; 2], a: &'b [T; 2], s: T) ->  &'a mut [T; 2] {
+pub fn ssub<'a, 'b, T: Copy + Num>(out: &'a mut [T; 2], a: &'b [T; 2], s: T) -> &'a mut [T; 2] {
     out[0] = a[0] - s;
     out[1] = a[1] - s;
     out
